@@ -5,7 +5,8 @@
 
     SDL is the Specification and Description Language (Z100 standard from ITU)
 
-    Copyright (c) 2012-2019 European Space Agency
+    Copyright (c) 2012-2022 Maxime Perrotin
+    Copyright (c) 2012-2022 European Space Agency
 
     Designed and implemented by Maxime Perrotin
 
@@ -27,10 +28,10 @@ from functools import partial
 from itertools import chain
 import re
 
-from PySide2.QtCore import *
-from PySide2.QtGui import *
-from PySide2.QtWidgets import *
-from PySide2.QtUiTools import QUiLoader
+from PySide6.QtCore import *
+from PySide6.QtGui import *
+from PySide6.QtWidgets import *
+from PySide6.QtUiTools import QUiLoader
 
 # import resource file to get the configuration widget
 from . import icons
@@ -62,10 +63,16 @@ class Record(genericSymbols.HorizontalSymbol):
     _terminal_followers = []
     textbox_alignment = (Qt.AlignTop | Qt.AlignHCenter)
 
+    # Minimum size for symbol
+    min_size = (70, 35)
+
     def __init__(self, node, graph):
         ''' Initialization: compute the polygon shape '''
         self.name = node['name']
-        super(Record, self).__init__(x=node['pos'][0],
+        # Keep the full path to the state (with parent state names)
+        # This is needed for symbol highlightning of parallel states
+        self.path = node['path']
+        super().__init__(x=node['pos'][0],
                 y=node['pos'][1], text=self.name)
         self.set_shape(node['width'], node['height'])
         self.setBrush(QBrush(QColor(255, 255, 202)))
@@ -87,7 +94,7 @@ class Record(genericSymbols.HorizontalSymbol):
         self.setPath(path)
         LOG.debug ("Set shape of state " + str(self))
         #LOG.debug(traceback.print_stack())
-        super(Record, self).set_shape(width, height)
+        super().set_shape(width, height)
 
     def resize_item(self, _):
         ''' Redefine the resizing function - forbid resizing '''
@@ -98,8 +105,6 @@ class Record(genericSymbols.HorizontalSymbol):
         # must return the state name only, as it is used in the renderer
         # in V2, there was a separate __unicode__ function
         return self.name
-        #return('Record ' + self.name + ' at pos ' + str(self.pos()) +
-        #       ' bounding rect = ' + str(self.boundingRect()))
 
     def mouse_release(self, _):
         ''' After moving item, ask dot to recompute the edges '''
@@ -128,7 +133,7 @@ class Point(genericSymbols.HorizontalSymbol):
             label = self.name[0:-6]
         else:
             label=''
-        super(Point, self).__init__(x=node['pos'][0], y=node['pos'][1],
+        super().__init__(x=node['pos'][0], y=node['pos'][1],
                 text=label)
         self.set_shape(node['width'], node['height'])
         self.setBrush(QBrush(Qt.black))
@@ -141,7 +146,7 @@ class Point(genericSymbols.HorizontalSymbol):
         path = QPainterPath()
         path.addEllipse(0, 0, width, height)
         self.setPath(path)
-        super(Point, self).set_shape(width, height)
+        super().set_shape(width, height)
 
     def resize_item(self, _):
         ''' Redefine the resizing function - forbid resizing '''
@@ -175,7 +180,7 @@ class Diamond(genericSymbols.HorizontalSymbol):
     def __init__(self, node, graph):
         ''' Initialization: compute the polygon shape '''
         self.name = node['name']
-        super(Diamond, self).__init__(x=node['pos'][0], y=node['pos'][1])
+        super().__init__(x=node['pos'][0], y=node['pos'][1])
         self.set_shape(node['width'], node['height'])
         self.graph = graph
 
@@ -188,7 +193,7 @@ class Diamond(genericSymbols.HorizontalSymbol):
         path.lineTo(0, height / 2)
         path.lineTo(width / 2, 0)
         self.setPath(path)
-        super(Diamond, self).set_shape(width, height)
+        super().set_shape(width, height)
 
     def resize_item(self, _):
         ''' Redefine the resizing function - forbid resizing '''
@@ -222,7 +227,7 @@ class Stop(genericSymbols.HorizontalSymbol):
     def __init__(self, node, graph):
         ''' Initialization: compute the polygon shape '''
         self.name = node['name']
-        super(Stop, self).__init__(x=node['pos'][0], y=node['pos'][1],
+        super().__init__(x=node['pos'][0], y=node['pos'][1],
                                    text=self.name)
         self.set_shape(node['width'], node['height'])
         self.graph = graph
@@ -237,7 +242,7 @@ class Stop(genericSymbols.HorizontalSymbol):
         path.moveTo(width, 0)
         path.lineTo(0, height)
         self.setPath(path)
-        super(Stop, self).set_shape(width, height)
+        super().set_shape(width, height)
 
     def resize_item(self, _):
         ''' Redefine the resizing function - forbid resizing '''
@@ -354,6 +359,8 @@ def preprocess_nodes(my_graph, bounding_rect, dpi):
         new_node['shape'] = node.get('shape') or 'record'
         # node main name
         new_node['name'] = node['name']
+        # node full path (for nested/parallel states)
+        new_node['path'] = node['comment']
         try:
             # node complete label (can contain several compartments)
             properties = (
@@ -504,8 +511,9 @@ def render_statechart(scene, graphtree=None, keep_pos=False, dump_gfx=''):
         graph = graphtree.get('graph', None) or dotgraph.AGraph('taste.dot')
         config = " ".join("{name}={val}".format(name=name, val=val)
                 for name, val in graphtree['config'].items())
-    except IOError:
+    except IOError as err:
         LOG.info('No statechart to display....')
+        LOG.debug(str(err))
         raise
     graph.graph_attr.update(dpi='72.0')
     EDGES[:] = graph.edges()
@@ -698,7 +706,7 @@ def create_dot_graph(root_ast,
         ui_file.close()
         rightList.addItems(list(valid_inputs))
         leftList.addItems(list(input_signals - valid_inputs))
-        go = dialog.exec_()
+        go = dialog.exec()
         valid_inputs.clear()
         for idx in range(rightList.count()):
             valid_inputs.add(rightList.item(idx).text())
@@ -718,8 +726,23 @@ def create_dot_graph(root_ast,
                            fixedsize='true',
                            width=10.0 / 72.0)
         else:
+            # Find the path to the state, this is needed to be able to
+            # highlight properly the parallel states in simulation
+            for s in root_ast.content.states:
+                # State may have commas or *
+                statelist = [a.lower() for a in s.statelist]
+                if state.lower() in statelist:
+                    path = s.path
+                    break
+            else:
+                # Should never happen
+                LOG.error('Bug in statechart rendering - please report')
+                path = []
+            path_str = ".".join(elem.split()[1] for elem in path + [f"S {state}"]
+                                if not elem.startswith("PROCESS"))
             graph.add_node(state,
                            label=state,
+                           comment=path_str,
                            shape='record',
                            style='rounded')
 
@@ -820,7 +843,7 @@ def create_dot_graph(root_ast,
                 label = ''
                 diamond += 1
             for term in next_states:
-                if term.inputString.strip() == '-':
+                if term.inputString.strip() in ('-', '-*'):
                     target = state
                 else:
                     target = term.inputString.lower() or ' '
@@ -861,7 +884,7 @@ def create_dot_graph(root_ast,
     for each in root_ast.composite_states:
         LOG.debug ("Recursive generation of statechart: " + each.statename)
         # Recursively generate the graphs for nested states
-        # Inherit from the list of signals from the higer level state
+        # Inherit from the list of signals from the higher level state
         #each.input_signals = root_ast.input_signals
         each.all_signals = valid_inputs
         ret['children'][each.statename] = create_dot_graph(each,
